import { Program } from '@project-serum/anchor';
import { TokenBridge } from '@certusone/wormhole-sdk/lib/cjs/solana/types/tokenBridge';
import { NftBridge } from '@certusone/wormhole-sdk/lib/cjs/solana/types/nftBridge';
import { Wormhole as WormholeCore } from '@certusone/wormhole-sdk/lib/cjs/solana/types/wormhole';
import { ChainName, ChainId, Contracts, TokenBridgeRelayer, ContractsAbstract, Wormhole } from '@wormhole-foundation/connect-sdk';
/**
 * @category Solana
 */
export declare class SolContracts extends ContractsAbstract {
    protected _contracts: Map<ChainName, any>;
    protected wormhole: Wormhole;
    constructor(wormholeBase: Wormhole);
    get connection(): any;
    getContracts(chain: ChainName | ChainId): Contracts | undefined;
    mustGetContracts(chain: ChainName | ChainId): Contracts;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, undefined if not found
     */
    getCore(chain?: ChainName | ChainId): Program<WormholeCore> | undefined;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    mustGetCore(chain?: ChainName | ChainId): Program<WormholeCore>;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, undefined if not found
     */
    getBridge(chain?: ChainName | ChainId): Program<TokenBridge> | undefined;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    mustGetBridge(chain?: ChainName | ChainId): Program<TokenBridge>;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain?: ChainName | ChainId): Program<NftBridge> | undefined;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain: ChainName | ChainId): Program<NftBridge>;
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, undefined if not found
     */
    getTokenBridgeRelayer(chain?: ChainName | ChainId): TokenBridgeRelayer | undefined;
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, errors if not found
     */
    mustGetTokenBridgeRelayer(chain: ChainName | ChainId): TokenBridgeRelayer;
}
