"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.redeemAndUnwrapOnSolana = exports.redeemOnSolana = void 0;
const web3_js_1 = require("@solana/web3.js");
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const tokenBridge_1 = require("./tokenBridge");
const spl_token_1 = require("@solana/spl-token");
async function redeemOnSolana(connection, bridgeAddress, tokenBridgeAddress, payerAddress, signedVaa, feeRecipientAddress, commitment) {
    const parsed = (0, connect_sdk_1.parseTokenTransferVaa)(signedVaa);
    const createCompleteTransferInstruction = parsed.tokenChain == connect_sdk_1.MAINNET_CHAINS.solana
        ? tokenBridge_1.createCompleteTransferNativeInstruction
        : tokenBridge_1.createCompleteTransferWrappedInstruction;
    const transaction = new web3_js_1.Transaction().add(createCompleteTransferInstruction(connection, tokenBridgeAddress, bridgeAddress, payerAddress, parsed, feeRecipientAddress));
    const { blockhash } = await connection.getLatestBlockhash(commitment);
    transaction.recentBlockhash = blockhash;
    transaction.feePayer = new web3_js_1.PublicKey(payerAddress);
    return transaction;
}
exports.redeemOnSolana = redeemOnSolana;
async function redeemAndUnwrapOnSolana(connection, bridgeAddress, tokenBridgeAddress, payerAddress, signedVaa, commitment) {
    const parsed = (0, connect_sdk_1.parseTokenTransferVaa)(signedVaa);
    const targetPublicKey = new web3_js_1.PublicKey(parsed.to);
    const targetAmount = await (0, spl_token_1.getMint)(connection, spl_token_1.NATIVE_MINT, commitment).then((info) => parsed.amount * BigInt(Math.pow(10, info.decimals - connect_sdk_1.MAX_VAA_DECIMALS)));
    const rentBalance = await (0, spl_token_1.getMinimumBalanceForRentExemptAccount)(connection, commitment);
    if (Buffer.compare(parsed.tokenAddress, spl_token_1.NATIVE_MINT.toBuffer()) != 0) {
        return Promise.reject('tokenAddress != NATIVE_MINT');
    }
    const payerPublicKey = new web3_js_1.PublicKey(payerAddress);
    const ancillaryKeypair = web3_js_1.Keypair.generate();
    const completeTransferIx = (0, tokenBridge_1.createCompleteTransferNativeInstruction)(connection, tokenBridgeAddress, bridgeAddress, payerPublicKey, signedVaa);
    //This will create a temporary account where the wSOL will be moved
    const createAncillaryAccountIx = web3_js_1.SystemProgram.createAccount({
        fromPubkey: payerPublicKey,
        newAccountPubkey: ancillaryKeypair.publicKey,
        lamports: rentBalance,
        space: spl_token_1.ACCOUNT_SIZE,
        programId: spl_token_1.TOKEN_PROGRAM_ID,
    });
    //Initialize the account as a WSOL account, with the original payerAddress as owner
    const initAccountIx = (0, spl_token_1.createInitializeAccountInstruction)(ancillaryKeypair.publicKey, spl_token_1.NATIVE_MINT, payerPublicKey);
    //Send in the amount of wSOL which we want converted to SOL
    const balanceTransferIx = (0, spl_token_1.createTransferInstruction)(targetPublicKey, ancillaryKeypair.publicKey, payerPublicKey, targetAmount.valueOf());
    //Close the ancillary account for cleanup. Payer address receives any remaining funds
    const closeAccountIx = (0, spl_token_1.createCloseAccountInstruction)(ancillaryKeypair.publicKey, //account to close
    payerPublicKey, //Remaining funds destination
    payerPublicKey);
    const { blockhash } = await connection.getLatestBlockhash(commitment);
    const transaction = new web3_js_1.Transaction();
    transaction.recentBlockhash = blockhash;
    transaction.feePayer = payerPublicKey;
    transaction.add(completeTransferIx, createAncillaryAccountIx, initAccountIx, balanceTransferIx, closeAccountIx);
    transaction.partialSign(ancillaryKeypair);
    return transaction;
}
exports.redeemAndUnwrapOnSolana = redeemAndUnwrapOnSolana;
//# sourceMappingURL=redeem.js.map